/**
    This class models circles in the plane.

    Notice that the instance variables are private.

    Notice that several of the methods take parameters.
*/

public class Circle
{
   // Declare three instance variables for a Circle object.
   // Make them private instance variables.
   private double xCenter;
   private double yCenter;
   private double radius;

   /**
       Define a method for initializing this circle's instance variables.
   */
   public void initialize(double x, double y, double r)
   {
      xCenter = x;
      yCenter = y;
      radius = r;  // what should we do about a negative radius?
   }

   /**
       An accessor method to return the radius.
   */
   public double getRadius()
   {
      return radius;
   }

   /**
       An accessor method to return the x-value of the center.
   */
   public double getX()
   {
      return xCenter;
   }

   /**
       An accessor method to return the y-value of the center.
   */
   public double getY()
   {
      return yCenter;
   }

   /**
       A method to compute this circle's area.
   */
   public double computeArea()
   {
      return Math.PI*Math.pow(radius,2);
   }

   /**
       A method to compute this cirlcle's perimeter.
   */
   public double computePerimeter()
   {
      return 2*Math.PI*radius;
   }

   /**
       A mutator method to move this circle to a new location.
   */
   public void moveTo(double x, double y)
   {
      xCenter = x;
      yCenter = y;
   }

   /**
       A mutator method to move this circle by a given amount.
   */
   public void moveBy(double x, double y)
   {
      xCenter = xCenter + x;
      yCenter = yCenter + y;
//    xCenter += x;
//    yCenter += y;
   }

   /**
       A mutator method to move this circle up (or down) from
       where it currently is.
   */
   public void moveUp(double distance)
   {
      xCenter += distance;
   }

   /**
       A mutator method to move this circle right (or left) from
       where it currently is.
   */
   public void moveRight(double distance)
   {
      yCenter += distance;
   }

   /**
       A mutator method to grow (or shrink) this circle.
   */
   public void grow(double change)
   {
      radius += change;  // what about a possible negative radius?
   }

   /**
       A method to determine if this circle
       intersects (overlaps) another circle.
   */
   public boolean intersect(Circle circle2)
   {
      // compute the distance between the centers
      double deltaX = this.xCenter - circle2.xCenter;
      double deltaY = this.yCenter - circle2.yCenter;
      double distance = Math.sqrt( deltaX*deltaX + deltaY*deltaY );

      return ( distance < (this.radius + circle2.radius) );
   }

   /**
       A method to determine if this circle
       is equal to another circle.
   */
   public boolean equals(Circle circle2)
   {
      return ( (this.xCenter == circle2.xCenter)
            && (this.yCenter == circle2.yCenter)
            && (this.radius  == circle2.radius  ));
   }

   /**
       A method to print out this Circle object's data.
   */
   public void writeOutput()
   {
      System.out.println("This circle has the following properties:");
      System.out.println("\tcenter = (" + xCenter + "," + yCenter + ")" );
      System.out.println("\tradius  = " + radius);
   }

}//Circle
