/**
   This class defines Temperature objects.
<p>
   A temperature is stored in degrees Kelvin, but this implementation
   detail is hidden from the user of Temperature objects by the
   public interface (i.e., the set and get methods). The public interface
   always uses degrees Celsius and Fahrenheit.
<p>
   The public interface of this class is meant to prevent someone from
   storing a temperature value thinking that the number is in one scale
   but then using the number later on thinking that it is in the other scale.
   (This kind of mistake has really happened in real code. See
   <a href="https://en.wikipedia.org/wiki/Mars_Climate_Orbiter#Cause_of_failure">
      https://en.wikipedia.org/wiki/Mars_Climate_Orbiter#Cause_of_failure
   </a>
*/

public class Temperature
{
   /**
      An instance variable that records a temperature value
      in the degrees Kelvin scale.

      This variable is "private" so that only our code in
      this class file can manipulate it. Our goal is to
      prevent someone from misinterpreting this number.
   */
   private double degreesKelvin;


   /**
      A method for changing the temperature value stored in this object.
      This method assumes that its parameter is a temperature in the
      Celsius scale. If the given temperature value is unrealistic (below
      absolute zero), then it is forced to absolute zero and a value of false
      is returned.
   */
   public boolean setTemperatureC(double degreesC)
   {
      boolean result;
       if (degreesC >= -273)  //validate the data
       {
           degreesKelvin = degreesC + 273;
           result = true;  // report that there was no problem with the parameter
       }
       else
       {
           degreesKelvin = 0;
           result = false;  // report that there was a problem with the parameter
        }
        return result;
   }

   /**
      A method for changing the temperature value stored in this object.
      This method assumes that its parameter is a temperature in the
      Fahrenheit scale. If the given temperature value is unrealistic (below
      absolute zero), then it is forced to absolute zero.
   */
   public void setTemperatureF(double degreesF)
   {
       degreesKelvin = (degreesF - 32)/1.8 + 273;
       //now validate the data
       if ( degreesKelvin < 0 ) degreesKelvin = 0;
   }

   /**
      A method for reading the temperature value stored in this object.
      This method returns a temperature in the Celsius scale.
   */
   public double getTemperatureC()
   {
       return degreesKelvin - 273;
   }

   /**
      A method for reading the temperature value stored in this object.
      This method returns a temperature in the Fahrenheit scale.
   */
   public double getTemperatureF()
   {
       return (degreesKelvin - 273)*1.8 + 32;
   }

   /**
      A method to compare this temperature object with
      another temperature object.
      (See pages 235-239 of the textbook.)
   */
   public boolean equals(Temperature t)
   {
      return ( this.degreesKelvin == t.degreesKelvin );
   }

}//Temperature
